package fr.itsee.zelyx;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.content.pm.ActivityInfo;
import android.os.AsyncTask;
import android.os.Bundle;
import android.provider.Settings;
import android.support.v7.app.AppCompatActivity;
import android.text.Editable;
import android.text.TextWatcher;
import android.view.MotionEvent;
import android.view.View;
import android.view.inputmethod.InputMethodManager;
import android.widget.Button;
import android.widget.EditText;
import android.widget.GridLayout;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.ScrollView;
import android.widget.TextView;
import android.widget.Toast;

import com.squareup.picasso.Picasso;

import org.json.JSONException;
import org.json.JSONObject;

import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static java.lang.Integer.parseInt;

public class FicheProduitActivity extends AppCompatActivity {


    private List<Produit> listProduitRef;
    private List<Integer> listeImageIndex;
    private GridLayout grilleCouleurs;
    private TextView ref, prix, textStockTotal, textStockCouleur, editQte, textQteProduitPack, titreEditStockTxt;
    private ImageView selectedImage;
    private Button ajouter;
    private Integer qteProduit, qteProduitUnite;
    private EditText editStockTxt;
    private ScrollView couleursScrollView;

    @Override
    public void onBackPressed() {
        Intent returnIntent = new Intent();
        setResult(Activity.RESULT_CANCELED, returnIntent);
        finish();
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_fiche_produit);

        if (android.provider.Settings.System.getInt(getContentResolver(),
                Settings.System.ACCELEROMETER_ROTATION, 0) == 1) {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_SENSOR_PORTRAIT);
        } else {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);
        }

        final DecimalFormat df = new DecimalFormat("#,###,##0.00");
        df.setMaximumFractionDigits(2);//arrondi à 2 chiffres après la virgule
        df.setMinimumFractionDigits(2);
        df.setDecimalSeparatorAlwaysShown(true);

        grilleCouleurs = findViewById(R.id.couleur);
        ref = findViewById(R.id.ref);
        prix = findViewById(R.id.prix);
        ajouter = findViewById(R.id.ajouter);
        textStockTotal = findViewById(R.id.textStockTotal);
        textStockCouleur = findViewById(R.id.textStockCouleur);
        editQte = findViewById(R.id.editQte);
        textQteProduitPack = findViewById(R.id.qteProduit);
        qteProduit = 1;
        editStockTxt = findViewById(R.id.editStockTxt);
        titreEditStockTxt = findViewById(R.id.titreEditStockTxt);
        couleursScrollView = findViewById(R.id.couleursScrollView);

        editStockTxt.setVisibility(View.GONE);
        titreEditStockTxt.setVisibility(View.GONE);

        Intent intent = getIntent();
        final Produit p = intent.getParcelableExtra("produit");

        editQte.setText("" + qteProduit);

        ref.setText(p.getInformations().toUpperCase() + " " + p.getRef());
        textStockTotal.setText("Stock total: " + p.getQteTotalRef() + "pcs");
        textStockCouleur.setText("Stock \"" + p.getColoris() + "\": " + p.getStock() + "pcs");
        textQteProduitPack.setText("(" + p.getQuantite_pack() + ")");
        if (p.getPrixPromo() > 0) {
            prix.setText("*" + df.format(p.getQuantite_pack() * p.getPrixPromo()) + " € HT");
        } else {
            prix.setText("" + df.format(p.getQuantite_pack() * p.getPrix()) + " € HT");
        }

        qteProduitUnite = 1 * p.getQuantite_pack();

        listProduitRef = new ArrayList<>();
        listeImageIndex = new ArrayList<>();

        for (Produit produit : CommandesActivity.listeAllProduits) {
            if (produit.getRef().equals(p.getRef())) {
                listProduitRef.add(produit);
                listeImageIndex.add(CommandesActivity.listeAllProduits.indexOf(produit));
            }
        }

        LinearLayout.LayoutParams lp = new LinearLayout.LayoutParams(LinearLayout.LayoutParams.WRAP_CONTENT, LinearLayout.LayoutParams.WRAP_CONTENT);
        lp.setMargins(5, 5, 5, 5);

        int i = 0;
        for (Produit pr : listProduitRef) {
            ImageView image = new ImageView(getApplicationContext());
            if (!pr.getLien_image().equals("")) {
                String imageURL = MainActivity.backOfficeURLIMG + pr.getLien_image();
                /*Picasso.with(getApplicationContext()).load(imageURL).into(image);*/
                Picasso.with(getApplicationContext()).load(imageURL).placeholder(R.drawable.image_not_found).error(R.drawable.image_not_found).into(image);
            } else {
                image.setImageResource(R.drawable.image_not_found);
            }

            image.setLayoutParams(lp);
            image.setId(i);
            if (pr.getColoris().equals(p.getColoris())) {
                selectedImage = image;
                image.setBackground(getDrawable(R.drawable.selected_color));

                /*int qte = 0;
                try {
                    qte = CommandesActivity.getProduitInCommande(pr.getCode128()).getQte();
                } catch (Exception e) {
                }*/

                if (pr != null) {
                    if (pr.getStock() - parseInt(editQte.getText().toString()) <= -1) {
                        ajouter.setEnabled(false);
                        ajouter.setBackground(getDrawable(R.drawable.button_style_disable));
                    } else {
                        ajouter.setEnabled(true);
                        //ajouter.setBackground(getDrawable(R.color.colorCommande));
                        ajouter.setBackground(getDrawable(R.drawable.button_style_selected));
                    }
                } else {
                    ajouter.setEnabled(true);
                    ajouter.setBackground(getDrawable(R.drawable.button_style_selected));
                }
            } else {
                image.setBackground(getDrawable(R.drawable.unselected_color));
            }

            grilleCouleurs.addView(image, 0);
            image.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    selectedImage.setBackground(getDrawable(R.drawable.unselected_color));
                    selectedImage = ((ImageView) view);
                    selectedImage.setBackground(getDrawable(R.drawable.selected_color));

                    Produit p = listProduitRef.get(selectedImage.getId());

                    ref.setText(p.getInformations().toUpperCase() + " " + p.getRef());

                    qteProduit = parseInt(editQte.getText().toString()) * p.getQuantite_pack();
                    qteProduitUnite = qteProduit;
                    textQteProduitPack.setText("(" + p.getQuantite_pack() + ")");

                    //Si prixPromo > 0 alors appliquer ce prix
                    if (p.getPrixPromo() > 0) {
                        prix.setText("*" + df.format(qteProduit * p.getQuantite_pack() * p.getPrixPromo()) + " € HT");
                        p.setSiPromo(1);
                        p.setPrix(p.getPrixPromo()); //Applique le prix promo pour le calcul
                    } else {
                        prix.setText("" + df.format((qteProduit * p.getQuantite_pack() * p.getPrix())) + " € HT");
                        p.setSiPromo(0);
                    }
                    textQteProduitPack.setText("(" + p.getQuantite_pack() + ")");

                    textStockTotal.setText("Stock total: " + p.getQteTotalRef() + "pcs");
                    textStockCouleur.setText("Stock \"" + p.getColoris() + "\": " + p.getStock() + "pcs");
                }
            });
            i += 1;

            image.getLayoutParams().height = 90;
            image.getLayoutParams().width = 75;

            //Initialisation à 1 produit par défaut
            //qteProduit = 1;
            editQte.setText("" + qteProduit);

            editStockTxt.addTextChangedListener(new TextWatcher() {

                public void afterTextChanged(Editable s) {
                }

                public void beforeTextChanged(CharSequence s, int start, int count, int after) {}

                public void onTextChanged(CharSequence s, int start, int before, int count) {
                    if (s.length() < 1 || start >= s.length() || start < 0)
                        return;

                    // If it was Enter
                    if (s.subSequence(start, start + 1).toString().equalsIgnoreCase("\n")) {

                        // Change text to show without '\n'
                        String s_text = start > 0 ? s.subSequence(0, start).toString() : "";
                        s_text += start < s.length() ? s.subSequence(start + 1, s.length()).toString() : "";
                        editStockTxt.setText(s_text);

                        // Move cursor to the end of the line
                        editStockTxt.setSelection(s_text.length());

                        new UpdateStockProductAsync().execute(p.getCode128(), editStockTxt.getText().toString());

                        String inputStockTxt = editStockTxt.getText().toString();
                        if (inputStockTxt.length() >0) {
                            p.setStock(parseInt(editStockTxt.getText().toString()));
                            textStockTotal.setText("");
                            textStockCouleur.setText("Stock \"" + p.getColoris() + "\": " + p.getStock() + "pcs");
                        }

                        if (getCurrentFocus() != null) {
                            InputMethodManager imm = (InputMethodManager) getSystemService(Context.INPUT_METHOD_SERVICE);
                            imm.hideSoftInputFromWindow(getCurrentFocus().getWindowToken(), 0);
                        }
                    }
                }

                class UpdateStockProductAsync extends AsyncTask<String, String, String> {

                    final String BASE_URL = MainActivity.backOfficeURL;

                    @Override
                    protected void onPreExecute() {
                        super.onPreExecute();
                    }

                    protected String doInBackground(String... args) {

                                String code128Txt = args[0];

                                //Mise à jour du stock du produit en fonction du code 128
                                String inputStockTxt = args[1];

                        if (inputStockTxt.length() > 0) {
                                try {
                                    HttpJsonParser httpJsonParser5 = new HttpJsonParser();
                                    Map<String, String> httpParams5 = new HashMap<>();
                                    httpParams5.put("code128", code128Txt);
                                    httpParams5.put("stock", inputStockTxt);
                                    JSONObject jsonObject5 = httpJsonParser5.makeHttpRequest(
                                            BASE_URL + "updateStockProduct.php", "POST", httpParams5);
                                    int success5 = jsonObject5.getInt("success");
                                    String message5 = jsonObject5.getString("message");
                                } catch (JSONException e) {
                                    e.printStackTrace();
                                }
                            }

                        return null;
                    }

                    protected void onPostExecute(String file_url) {

                    }
                }
            });
        }

       /* editQte.addTextChangedListener(new TextWatcher() {
            @Override
            public void beforeTextChanged(CharSequence charSequence, int i, int i1, int i2) {
            }

            @Override
            public void onTextChanged(CharSequence charSequence, int i, int i1, int i2) {

            }

            @Override
            public void afterTextChanged(Editable editable) {
                if (!editQte.getText().toString().isEmpty()) {
                    qteProduit = parseInt(editQte.getText().toString());
                    if (p.getPrixPromo() > 0) {
                        prix.setText("*" + df.format((qteProduit * p.getQuantite_pack() * p.getPrixPromo())) + " € HT");
                    } else {
                        prix.setText("" + df.format(qteProduit * p.getQuantite_pack() * p.getPrix()) + " € HT");
                        p.setSiPromo(0);
                    }
                    textQteProduitPack.setText("(" + p.getQuantite_pack() + ")");
                    qteProduitUnite = qteProduit * p.getQuantite_pack();
                }
            }
        });*/

        textStockCouleur.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                if (grilleCouleurs.getVisibility() == View.VISIBLE) {
                    couleursScrollView.setVisibility(View.GONE);
                    titreEditStockTxt.setVisibility(View.VISIBLE);
                    editStockTxt.setVisibility(View.VISIBLE);
                } else {
                    editStockTxt.setVisibility(View.GONE);
                    titreEditStockTxt.setVisibility(View.GONE);
                    couleursScrollView.setVisibility(View.VISIBLE);
                }
            }
        });
    }

    @Override
    public void onWindowFocusChanged(boolean hasFocus) {
        if (android.provider.Settings.System.getInt(getContentResolver(),
                Settings.System.ACCELEROMETER_ROTATION, 0) == 1) {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_SENSOR_PORTRAIT);
        } else {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);
        }

    }

    @Override
    protected void onResume() {
        super.onResume();

        if (android.provider.Settings.System.getInt(getContentResolver(),
                Settings.System.ACCELEROMETER_ROTATION, 0) == 1) {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_SENSOR_PORTRAIT);
        } else {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);
        }
    }

    public void ajouter(View v) {
        Intent returnIntent = new Intent();
        //Permet de définir la quantité manuellement
        listProduitRef.get(selectedImage.getId()).setQte(qteProduitUnite);
        returnIntent.putExtra("produit", listProduitRef.get(selectedImage.getId()));
        setResult(Activity.RESULT_OK, returnIntent);
        qteProduit = 1;
        qteProduitUnite = 1;
        finish();
    }

    public void annuler(View v) {
        Intent returnIntent = new Intent();
        setResult(Activity.RESULT_CANCELED, returnIntent);
        qteProduit = 1;
        finish();
    }

    @Override
    protected void onPause() {
        super.onPause();this.overridePendingTransition(0, 0);
    }

    public void moins(View v) {
        Intent intent = getIntent();
        Produit p = intent.getParcelableExtra("produit");
        if (qteProduit > 1) {
            qteProduit -= 1;
            qteProduitUnite -= 1 * p.getQuantite_pack();
            editQte.setText("" + qteProduit);
        } else {
            qteProduit = 1;
            qteProduitUnite = 1 * p.getQuantite_pack();
            editQte.setText("" + qteProduit);
        }
        final DecimalFormat df = new DecimalFormat("0.00");
        df.setMaximumFractionDigits(2);//arrondi à 2 chiffres après la virgule
        df.setMinimumFractionDigits(2);
        df.setDecimalSeparatorAlwaysShown(true);
        if (p.getPrixPromo() > 0) {
            prix.setText("*" + df.format(qteProduit * p.getQuantite_pack() * p.getPrixPromo()) + " € HT");
            p.setSiPromo(1);
            p.setPrix(p.getPrixPromo()); //Applique le prix promo pour le calcul
        } else {
            prix.setText("" + df.format(qteProduit * p.getQuantite_pack() * p.getPrix()) + " € HT");
            p.setSiPromo(0);
        }
        if (qteProduit > p.getStock()) {
            ajouter.setEnabled(false);
            ajouter.setBackground(getDrawable(R.drawable.button_style_disable));
        } else {
            ajouter.setEnabled(true);
            ajouter.setBackground(getDrawable(R.drawable.button_style_selected));
        }
    }

    public void plus(View v) {
        Intent intent = getIntent();
        Produit p = intent.getParcelableExtra("produit");
        if (qteProduitUnite <= p.getStock()) {
            qteProduit += 1;
            qteProduitUnite += 1 * p.getQuantite_pack();
            final DecimalFormat df = new DecimalFormat("0.00");
            df.setMaximumFractionDigits(2);//arrondi à 2 chiffres après la virgule
            df.setMinimumFractionDigits(2);
            df.setDecimalSeparatorAlwaysShown(true);
            if (p.getPrixPromo() > 0) {
                prix.setText("*" + df.format(qteProduit * p.getQuantite_pack() * p.getPrixPromo()) + " € HT");
                p.setSiPromo(1);
                p.setPrix(p.getPrixPromo()); //Applique le prix promo pour le calcul
            } else {
                prix.setText("" + df.format(qteProduit * p.getQuantite_pack() * p.getPrix()) + " € HT");
                p.setSiPromo(0);
            }
            editQte.setText("" + qteProduit);
        } else {
            if (p.getStock() >1) {
                Toast.makeText(getApplicationContext(), "Maximum: " + p.getStock() + " pièces!", Toast.LENGTH_SHORT).show();
            } else {
                Toast.makeText(getApplicationContext(), "Maximum: " + p.getStock() + " pièce!", Toast.LENGTH_SHORT).show();
            }
        }
        if (qteProduit > p.getStock()) {
            ajouter.setEnabled(false);
            ajouter.setBackground(getDrawable(R.drawable.button_style_disable));
        } else {
            ajouter.setEnabled(true);
            ajouter.setBackground(getDrawable(R.drawable.button_style_selected));
        }
    }

    //Masquer le clavier quand on appuie en dehors du champ
    @Override
    public boolean dispatchTouchEvent(MotionEvent ev) {
        if (getCurrentFocus() != null) {
            InputMethodManager imm = (InputMethodManager) getSystemService(Context.INPUT_METHOD_SERVICE);
            imm.hideSoftInputFromWindow(getCurrentFocus().getWindowToken(), 0);
        }
        return super.dispatchTouchEvent(ev);
    }

    private class RefreshProduitAsyncTask extends AsyncTask<Produit, String, String> {

        //BASE DE DONNES
        private final String BASE_URL = MainActivity.backOfficeURL;

        private Produit p;
        private int success;

        @Override
        protected String doInBackground(Produit... produits) {
            p = produits[0];

            HttpJsonParser httpJsonParser2 = new HttpJsonParser();
            Map<String, String> httpParams2 = new HashMap<>();

            httpParams2.put("code_128", p.getCode128());
            JSONObject jsonObject2 = httpJsonParser2.makeHttpRequest(
                    BASE_URL + "getStockProduit.php", "GET", httpParams2);

            try {
                success = jsonObject2.getInt("success");
                if (success == 1) {
                    JSONObject produit = jsonObject2.getJSONArray("data").getJSONObject(0);
                    p.setStock(parseInt(produit.getString("stock")));
                }

            } catch (JSONException e) {
                e.printStackTrace();
            }

            return null;
        }

        @Override
        protected void onPostExecute(String s) {
            super.onPostExecute(s);
            int qte = 0;
            try {
                p = CommandesActivity.getProduitInCommande(p.getCode128());
                //qte = p.getQte();
            } catch (Exception e) {
            }
            if (p != null) {
                //if (p.getStock() - parseInt(editQte.getText().toString()) - 1 <= -1) {
                if (p.getStock() - parseInt(editQte.getText().toString()) <= 0) {
                    //ajouter.setEnabled(false);
                    //ajouter.setBackground(getDrawable(R.drawable.button_style_disable));
                } else {
                    //ajouter.setEnabled(true);
                    //ajouter.setBackground(getDrawable(R.drawable.button_style));
                }
            } else {
                //ajouter.setEnabled(true);
                //ajouter.setBackground(getDrawable(R.drawable.button_style));
            }
        }
    }
}
