package fr.itsee.zelyx;

import android.content.Context;
import android.graphics.Color;
import android.graphics.drawable.Drawable;
import android.os.StrictMode;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.Filter;
import android.widget.Filterable;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.squareup.picasso.Picasso;

import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.List;

public class ProduitAdapter extends RecyclerView.Adapter<ProduitAdapter.MyViewHolder> implements Filterable {
//    public class ProduitAdapter extends RecyclerView.Adapter<fr.itsee.zelyx.ProduitAdapter.MyViewHolder> {

    public static List<Produit> listeAllProduits;
    public static List<Produit> listeAllProduitsFiltered;
    private Commande cmd;
    private OnItemClickListener mListener;
    private Context context;

    public ProduitAdapter(Commande cmd, Context context) {
        this.cmd = cmd;
        this.context = context;
    }

    @Override
    //Rechercher dans la recyclerview
    public Filter getFilter() {
        return new Filter() {
            @Override
            protected FilterResults performFiltering(CharSequence charSequence) {
                String charString = charSequence.toString();
                if (charString.isEmpty()) {
                    listeAllProduitsFiltered = listeAllProduits;
                } else {
                    List<Produit> filteredList = new ArrayList<>();
                    for (Produit row : filteredList) {

                        // name match condition. this might differ depending on your requirement
                        // here we are looking for name or phone number match
                        if (row.getRef().contains(charString.toLowerCase()) || row.getColoris().contains(charSequence)) {
                            filteredList.add(row);
                        }
                    }

                    listeAllProduitsFiltered = filteredList;
                }

                FilterResults filterResults = new FilterResults();
                filterResults.values = listeAllProduitsFiltered;
                return filterResults;
            }

            @Override
            protected void publishResults(CharSequence charSequence, FilterResults filterResults) {
                listeAllProduitsFiltered = (ArrayList<Produit>) filterResults.values;

                // refresh the list with filtered data
                notifyDataSetChanged();
            }
        };
    }

    public void setOnItemClickListener(OnItemClickListener listener) {
        mListener = listener;
    }

    public Commande getCmd() {
        return cmd;
    }

    public void setCmd(Commande cmd) {
        this.cmd = cmd;
    }

    @Override
    public MyViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View itemView = LayoutInflater.from(parent.getContext())
                .inflate(R.layout.ligne_produit, parent, false);
        //.inflate(R.layout.ligne_produit_zelyx, parent, false);
        return new MyViewHolder(itemView, mListener);
    }

    @Override
    public void onBindViewHolder(final MyViewHolder holder, final int position) {
        final Produit p = cmd.getListeProduit().get(position);
        /*if (p.getInformations().length()>9) {
            holder.ref.setText(p.getInformations().substring(0,7)+"\n"+p.getRef() + "\n" + p.getColoris());
        } else if (p.getInformations().length()>0) {
            holder.ref.setText(p.getInformations() + "\n" + p.getRef() + "\n" + p.getColoris());
        } else {
            holder.ref.setText(p.getRef() + "\n" + p.getColoris());
        }*/
        holder.ref.setText(p.getRef() + "\n" + p.getColoris());
        //DecimalFormat df = new DecimalFormat("0.00");
        DecimalFormat df = new DecimalFormat("#,###,##0.00");
        df.setMaximumFractionDigits(2);//arrondi à 2 chiffres après la virgule
        df.setMinimumFractionDigits(2);
        df.setDecimalSeparatorAlwaysShown(true);
        if (p.getPrixPromo() > 0) {
            holder.prix.setText("*" + df.format(p.getPrixPromo()));
        } else {
            holder.prix.setText("" + df.format(p.getPrix()));
        }
        //holder.coloris.setText(p.getColoris());
        holder.qte.setText("" + p.getQte());
        //if(p.getStock() - p.getQte() < -1){
        if (p.getStock() - p.getQte() < 0) {
            holder.qte.setTextColor(Color.RED);
        } else {
            holder.qte.setTextColor(Color.GRAY);
        }
        holder.prixTotale.setText("" + df.format(p.getPrixTotaleUnite()));

        if (!p.getLien_image().equals("")) {
            String imageURL = MainActivity.backOfficeURLIMG + p.getLien_image();
            Picasso.with(this.context).load(imageURL).placeholder(R.drawable.image_not_found).error(R.drawable.image_not_found).into(holder.photo);
        } else {
            holder.photo.setImageResource(R.drawable.image_not_found);
        }
    }

    @Override
    public int getItemCount() {
        if (cmd != null && cmd.getListeProduit() != null) {
            return cmd.getListeProduit().size();
        } else {
            return 0;
        }
    }

    public interface OnItemClickListener {
        void onPhotoClick(int position, Drawable imageDrawable, String lien_image);

        void onSupprClick(int position);

        void onPlusClick(int position);

        void onMoinsClick(int position);

        void onQuantiteClick(int position);

        void onRefClick(int position);

        void onPrixClick(int position);
    }

    public class MyViewHolder extends RecyclerView.ViewHolder {
        public TextView ref, prix, coloris, qte, prixTotale;
        public Button moins, plus, suppr;
        public ImageView photo;
        public LinearLayout editQte;


        public MyViewHolder(View view, final OnItemClickListener listener) {
            super(view);

            StrictMode.ThreadPolicy policy = new StrictMode.ThreadPolicy.Builder().permitAll().build();
            StrictMode.setThreadPolicy(policy);

            ref = view.findViewById(R.id.ref);
            prix = view.findViewById(R.id.prix);
            /*coloris = (TextView) view.findViewById(R.id.coloris);*/
            qte = view.findViewById(R.id.qte);
            prixTotale = view.findViewById(R.id.prixTotale);
            moins = view.findViewById(R.id.moins);
            plus = view.findViewById(R.id.plus);
            suppr = view.findViewById(R.id.suppr);
            photo = view.findViewById(R.id.photo);

            suppr.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null) {
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION) {
                            listener.onSupprClick(position);
                        }
                    }
                }
            });

            plus.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null) {
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION) {
                            listener.onPlusClick(position);
                        }
                    }
                }
            });

            moins.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null) {
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION) {
                            listener.onMoinsClick(position);
                        }
                    }
                }
            });

            photo.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null) {
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION) {
                            Drawable imageProduitDrawable = photo.getDrawable();
                            final Produit p = cmd.getListeProduit().get(position);
                            listener.onPhotoClick(position, imageProduitDrawable, p.getLien_image());
                        }
                    }
                }
            });

            ref.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null) {
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION) {
                            listener.onRefClick(position);
                        }
                    }
                }
            });
            /*coloris.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null){
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION){
                            listener.onQuantiteClick(position);
                        }
                    }
                }
            });*/
            qte.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null) {
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION) {
                            listener.onQuantiteClick(position);
                        }
                    }
                }
            });
            prix.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null) {
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION) {
                            listener.onPrixClick(position);
                        }
                    }
                }
            });
        }
    }
}